/*
Copyright (c) 2002-2011 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: 
*/
#include <e32math.h>
#include "roshambo.h"

TRoshambo::TRoshambo()
: iLocalPlayer(ENone), iOpponent(ENone){}

void TRoshambo::SinglePlayerGame(TElement aLocalPlayer)
	{
	iLocalPlayer = aLocalPlayer;
	TUint32 randomChoice = (Math::Random())%3;
	ASSERT( (randomChoice>=0) && (randomChoice<=3) ); 
	iOpponent = (TElement)randomChoice;
	}

//enum TElement {ENone = -1, ERock = 0, EPaper = 1, EScissors = 2};	
TRoshambo::TResult TRoshambo::CalculateResult() const
	{
	TResult result = ENoContest;
	
	if (iLocalPlayer==ENone)
		{
		if (iOpponent==ENone)
			result = ENoContest; // No contest if neither player selected
		else
			result = ELose;	  // Opponent won by default 
		}
		
	else if (iOpponent>iLocalPlayer)
		{
		if ( (iOpponent==EScissors) && (iLocalPlayer==ERock) ) // Player wins
			result = EWin;
		else // Opponent wins
			result = ELose;
		}
		
	else if (iLocalPlayer > iOpponent)
		{
		if ( (iLocalPlayer==EScissors) && (iOpponent==ERock) ) // Opponent wins
			result = ELose;
		else // Player wins
			result = EWin;
		}
		
	else if (iLocalPlayer==iOpponent)
		result = EDraw;
	
	else
		ASSERT(EFalse);; // Shouldn't get here		
		
	return (result);		
	}
